==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/screenshot/translations/screenshot_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>General Settings</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Select image format, which screenshots will be stored and sent in.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Force .jpg extension for JPEG format</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Screenshots quality</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 for autodetection, 0 for best file compression, 100 for best image quality.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Directory</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Screenshots directory path</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Screenshots filename prefix</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Enable directory size control</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Maximum directory size</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>ScreenShot images size limit</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Screenshot file format</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Paste image to chat window automatically</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Define, how many kbytes can shots take in the directory before plugin will warn you.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>Image size is bigger than maximal image size for this chat.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Unable to create direcotry %1 for storing screenshots!</translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation>Can&apos;t write file %1.
Access denied or other problem!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>Screenshot %1 has 0 size!
It should be bigger.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>ScreenShot</source>
        <translation>ScreenShot</translation>
    </message>
    <message>
        <source>Simple Shot</source>
        <translation>Simple Shot</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>With Chat Window Hidden</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Window Shot</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>ScreenShot size limit</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>Images size limit exceed: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Drag this icon onto the desired window</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Window Shot</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Crop</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/screenshot/translations/screenshot_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>General Settings</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Select image format, which screenshots will be stored and sent in.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Force .jpg extension for JPEG format</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Screenshots quality</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 for autodetection, 0 for best file compression, 100 for best image quality.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Directory</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Screenshots directory path</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Screenshots filename prefix</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Enable directory size control</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Maximum directory size</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>ScreenShot images size limit</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Screenshot file format</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Paste image to chat window automatically</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Define, how many kbytes can shots take in the directory before plugin will warn you.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>Image size is bigger than maximal image size for this chat.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Unable to create direcotry %1 for storing screenshots!</translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation>Can&apos;t write file %1.
Access denied or other problem!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>Screenshot %1 has 0 size!
It should be bigger.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>Simple Shot</source>
        <translation>Simple Shot</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>With Chat Window Hidden</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Window Shot</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotificationService</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation type="unfinished">ScreenShot size limit</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation type="unfinished">Images size limit exceed: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Drag this icon onto the desired window</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Window Shot</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Crop</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
</TS>
